FireResponse
============
FireResponse is a graphical tool to extract response times from measurements.
It can be started by running "FireResponse" in a terminal.

.. image:: FireResponseScreenshot.png
  :width: 400
  :alt: screenshot
